@@ -182,6 +182,7 @@ class SesansData(Data1D):
 
     *x* is spin echo length and *y* is polarization (P/P0).
     """
+    isSesans = True
     def __init__(self, **kw):
         Data1D.__init__(self, **kw)
         self.lam = None # type: Optional[np.ndarray]
@@ -300,6 +301,13 @@ class Source(object):
         self.wavelength = np.NaN
         self.wavelength_unit = "A"
 
+class Sample(object):
+    """
+    Sample attributes.
+    """
+    def __init__(self):
+        # type: () -> None
+        pass
 
 def empty_data1D(q, resolution=0.0, L=0., dL=0.):
     # type: (np.ndarray, float) -> Data1D
@@ -502,11 +510,13 @@ def _plot_result1D(data,         # type: Data1D
         if use_theory:
             # Note: masks merge, so any masked theory points will stay masked,
             # and the data mask will be added to it.
-            mtheory = masked_array(theory, data.mask.copy())
+            #mtheory = masked_array(theory, data.mask.copy())
+            theory_x = data.x[data.mask == 0]
+            mtheory = masked_array(theory)
             mtheory[~np.isfinite(mtheory)] = masked
             if view is 'log':
                 mtheory[mtheory <= 0] = masked
-            plt.plot(data.x, scale*mtheory, '-')
+            plt.plot(theory_x, scale*mtheory, '-')
             all_positive = all_positive and (mtheory > 0).all()
             some_present = some_present or (mtheory.count() > 0)
 
@@ -542,13 +552,14 @@ def _plot_result1D(data,         # type: Data1D
         #plt.axis('equal')
 
     if use_resid:
-        mresid = masked_array(resid, data.mask.copy())
+        theory_x = data.x[data.mask == 0]
+        mresid = masked_array(resid)
         mresid[~np.isfinite(mresid)] = masked
         some_present = (mresid.count() > 0)
 
         if num_plots > 1:
             plt.subplot(1, num_plots, use_calc + 2)
-        plt.plot(data.x, mresid, '.')
+        plt.plot(theory_x, mresid, '.')
         plt.xlabel("$q$/A$^{-1}$")
         plt.ylabel('residuals')
         plt.title('(model - Iq)/dIq')
