@@ -24,11 +24,13 @@ import numpy as np  # type: ignore
 
 from . import core
 from . import custom
+from . import kernelcl
 from . import product
 from . import generate
 from . import weights
 from . import modelinfo
 from .details import make_kernel_args, dispersion_mesh
+from .kernelcl import reset_environment
 
 # pylint: disable=unused-import
 try:
@@ -68,6 +70,18 @@ MODEL_BY_PATH = {}  # type: Dict[str, SasviewModelType]
 #: has changed since we last reloaded.
 _CACHED_MODULE = {}  # type: Dict[str, "module"]
 
+def reset_environment():
+    # type: () -> None
+    """
+    Clear the compute engine context so that the GUI can change devices.
+
+    This removes all compiled kernels, even those that are active on fit
+    pages, but they will be restored the next time they are needed.
+    """
+    kernelcl.reset_environment()
+    for model in MODELS.values():
+        model._model = None
+
 def find_model(modelname):
     # type: (str) -> SasviewModelType
     """
@@ -383,6 +397,12 @@ class SasviewModel(object):
             hidden.add('background')
             self._model_info.parameters.defaults['background'] = 0.
 
+        # Update the parameter lists to exclude any hidden parameters
+        self.magnetic_params = tuple(pname for pname in self.magnetic_params
+                                     if pname not in hidden)
+        self.orientation_params = tuple(pname for pname in self.orientation_params
+                                        if pname not in hidden)
+
         self._persistency_dict = {}
         self.params = collections.OrderedDict()
         self.dispersion = collections.OrderedDict()
@@ -673,7 +693,11 @@ class SasviewModel(object):
 
     def _calculate_Iq(self, qx, qy=None):
         if self._model is None:
-            self._model = core.build_model(self._model_info)
+            # Only need one copy of the compiled kernel regardless of how many
+            # times it is used, so store it in the class.  Also, to reset the
+            # compute engine, need to clear out all existing compiled kernels,
+            # which is much easier to do if we store them in the class.
+            self.__class__._model = core.build_model(self._model_info)
         if qy is not None:
             q_vectors = [np.asarray(qx), np.asarray(qy)]
         else:
@@ -796,6 +820,16 @@ class SasviewModel(object):
             value = self.params[par.name]
             return value, [value], [1.0]
 
+    @classmethod
+    def runTests(cls):
+        """
+        Run any tests built into the model and captures the test output.
+
+        Returns success flag and output
+        """
+        from .model_test import check_model
+        return check_model(cls._model_info)
+
 def test_cylinder():
     # type: () -> float
     """
@@ -883,7 +917,7 @@ def test_old_name():
 def magnetic_demo():
     Model = _make_standard_model('sphere')
     model = Model()
-    model.setParam('M0:sld', 8)
+    model.setParam('sld_M0', 8)
     q = np.linspace(-0.35, 0.35, 500)
     qx, qy = np.meshgrid(q, q)
     result = model.calculate_Iq(qx.flatten(), qy.flatten())
